<div align="center">

# purechance

[![GitHub](https://img.shields.io/badge/github-code-blue?label=GitHub)](https://github.com/oyghen/purechance)
[![PyPI](https://img.shields.io/pypi/v/purechance?label=PyPI)](https://pypi.org/project/purechance)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://github.com/oyghen/purechance/blob/main/LICENSE)
[![CI](https://github.com/oyghen/purechance/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/oyghen/purechance/actions/workflows/ci.yml)

</div>

```shell
uv tool install 'purechance[cli]'
```
